@@ -30,7 +30,7 @@ from .utils.df_utils import CloseAfterIteration, load_dataframe_from_sql, LoadSt
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
 from .utils.format_sniffer import find_url_extension, detect_format, FORMAT_ALIASES_WRITE_OPTIONS
 from .utils.nosql import connect_to_nosql
-from .utils.packages import install_packages
+#from .utils.packages import install_packages
 
 try:
     import mlflow
