@@ -1,6 +1,5 @@
 import unittest
 from dslibrary.utils import dbconn
-from dslibrary.sql.misc import sql_enquote_id
 
 
 class TestDBConn(unittest.TestCase):
@@ -170,16 +169,3 @@ class TestDBConn(unittest.TestCase):
         assert len(cursor._rows) == 500, "here we see the cache has been truncated"
         rows = cursor.fetchall()
         assert rows == [[_] for _ in range(1600, 2000)]
-
-    def test_sql_enquote_id(self):
-        self.assertEqual(sql_enquote_id("x"), 'x')
-        self.assertEqual(sql_enquote_id("x y"), '"x y"')
-        self.assertEqual(sql_enquote_id("x", always=True), '"x"')
-        self.assertEqual(sql_enquote_id("x", dotted=True), 'x')
-        self.assertEqual(sql_enquote_id("x.y", dotted=True), 'x.y')
-        self.assertEqual(sql_enquote_id("x.y z", dotted=True), 'x."y z"')
-        self.assertEqual(sql_enquote_id(("x", "y")), 'x.y')
-        self.assertEqual(sql_enquote_id(("x", "y z")), 'x."y z"')
-        self.assertEqual(sql_enquote_id("x", always=True, mode="mysql"), '`x`')
-        self.assertEqual(sql_enquote_id("AbC", "mysql"), 'AbC')
-        self.assertEqual(sql_enquote_id("AbC", "postgres"), '"AbC"')
